==> haskell-doclayout-0.2.0.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doclayout
version: 0.2.0.1
id: doclayout-0.2.0.1-QaV6Vjo41CLxujHKsTBZ7
key: doclayout-0.2.0.1-QaV6Vjo41CLxujHKsTBZ7
license: BSD-3-Clause
copyright: 2016-19 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/doclayout
synopsis: A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.
category: Text
abi: c06dfe63331590c43c93d4404f6c803a
exposed: True
exposed-modules:
    Text.DocLayout
import-dirs: /usr/lib/ghc-8.6.5/site-local/doclayout-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/doclayout-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/doclayout-0.2.0.1
hs-libraries: HSdoclayout-0.2.0.1-QaV6Vjo41CLxujHKsTBZ7
depends:
    base-4.12.0.0 mtl-2.2.2 safe-0.3.18-LtdH37oJsulDSBmeOJDMc3
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html: /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doclayout-0.2.0.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doclayout
version: 0.2.0.1
id: doclayout-0.2.0.1-9O4DcDivsBuQyCpvQDWq
key: doclayout-0.2.0.1-9O4DcDivsBuQyCpvQDWq
license: BSD-3-Clause
copyright: 2016-19 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/doclayout
synopsis: A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.
category: Text
abi: 5292e074e053954d1c796d432457440c
exposed: True
exposed-modules:
    Text.DocLayout
import-dirs: /usr/lib/ghc-8.6.5/site-local/doclayout-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/doclayout-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/doclayout-0.2.0.1
hs-libraries: HSdoclayout-0.2.0.1-9O4DcDivsBuQyCpvQDWq
depends:
    base-4.12.0.0 mtl-2.2.2 safe-0.3.18-LtdH37oJsulDSBmeOJDMc3
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html: /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
